This function generates an interactive visualization of all spectral signatures
contained in a dataset, based on the plotly library. It is highly flexible and
can be used to display: raw data downloaded directly from WISPstation, processed
data after QC, processed data after SR. The function’s distinctive feature is
its dynamic tooltip system: when hovering over a spectral curve, users can
instantly visualize the corresponding acquisition date and time, together with
all associated bio-optical parameters computed for that specific measurement.
Usage
wisp_plot_reflectance_data(
data,
legend_TSM = TRUE,
legend_Chla = TRUE,
legend_Kd = TRUE,
legend_cpc = TRUE,
legend_scatt = FALSE,
legend_ratio = FALSE,
legend_novoa_SPM = FALSE,
legend_novoa_TUR = FALSE,
legend_jiang_TSS = FALSE,
legend_gons_CHL = FALSE,
legend_gons740_CHL = FALSE,
legend_NDCI = FALSE,
legend_mishra_CHL = FALSE,
legend_hue_angle = FALSE,
legend_dom_wavelength = FALSE,
legend_OWT_class = FALSE,
legend_OWT_score = FALSE,
legend_OWT_z_dist = FALSE
)Arguments
- data
A
tibbleobtained by any of the functions provided by this package:wisp_get_reflectance_data(), or after QC and SR removal operations.- legend_TSM
A
logical. IfTRUE, the plot legend includes theTSMvalues. Default isTRUE.- legend_Chla
A
logical. IfTRUE, the plot legend includes theChlavalues. Default isTRUE.- legend_Kd
A
logical. IfTRUE, the plot legend includes theKdvalues. Default isTRUE.- legend_cpc
A
logical. IfTRUE, the plot legend includes thecpcvalues. Default isTRUE.- legend_scatt
A
logical. IfTRUE, the plot legend includes thescatteringvalues. Default isFALSE.- legend_ratio
A
logical. IfTRUE, the plot legend includes theratiovalues. Default isFALSE.- legend_novoa_SPM
A
logical. IfTRUE, the plot legend includes theNovoa_SPMvalues. Default isFALSE.- legend_novoa_TUR
A
logical. IfTRUE, the plot legend includes theNovoa_TURvalues. Default isFALSE.- legend_jiang_TSS
A
logical. IfTRUE, the plot legend includes theJiang_TSSvalues. Default isFALSE.- legend_gons_CHL
A
logical. IfTRUE, the plot legend includes theGons_CHLvalues. Default isFALSE.- legend_gons740_CHL
A
logical. IfTRUE, the plot legend includes theGons740_CHLvalues. Default isFALSE.- legend_NDCI
A
logical. IfTRUE, the plot legend includes theNDCIvalues. Default isFALSE.- legend_mishra_CHL
A
logical. IfTRUE, the plot legend includes theMishra_CHLvalues. Default isFALSE.- legend_hue_angle
A
logical. IfTRUE, the plot legend includes theHue_Anglevalues. Default isFALSE.- legend_dom_wavelength
A
logical. IfTRUE, the plot legend includes theDominant_Wavelengthvalues. Default isFALSE.- legend_OWT_class
A
logical. IfTRUE, the plot legend includes theOWT_class. Default isFALSE.- legend_OWT_score
A
logical. IfTRUE, the plot legend includes theOWT_score(membership grade). Default isFALSE.- legend_OWT_z_dist
A
logical. IfTRUE, the plot legend includes theOWT_z_dist(statistical distance). Default isFALSE.
Examples
# example code
if (FALSE) { # \dontrun{
## Not run:
wisp_plot_reflectance_data(
data = reflect_data_sr,
legend_TSM = TRUE,
legend_Chla = TRUE,
legend_Kd = TRUE,
legend_cpc = TRUE,
legend_scatt = FALSE,
legend_ratio = FALSE,
legend_novoa_SPM = FALSE,
legend_novoa_TUR = FALSE,
legend_jiang_TSS = FALSE,
legend_gons_CHL = FALSE,
legend_gons740_CHL = FALSE,
legend_NDCI = FALSE,
legend_mishra_CHL = FALSE,
legend_hue_angle = FALSE,
legend_dom_wavelength = FALSE,
legend_OWT_class = FALSE,
legend_OWT_score = FALSE,
legend_OWT_z_dist = FALSE
)
} # }
## End (Not run)